from pentest.command import JarvisCmd
import sys
__name__ = "sslyze"


def main():
	args_config = {
		'passthrough_args': ['--xml_out'],
		'output_args': [
			{
				'format': 'xml',
				'arg': '--xml_out'
			}
		]
	}

	cmd = JarvisCmd(sys.argv)
	cmd.set_args_config(args_config)

	for arg in cmd.args:
		if 'targets_in' in arg:
			target = 'multiple-hosts'
			break
	else:
		target = cmd.args[-1].replace('/', '_')

	cmd.run(target)
