#!/usr/bin/python
# -*- coding: utf-8 -*-

import argparse
import sys


class JarvisParser(argparse.ArgumentParser):
	"""
	Slightly modified argument parser dedicated to Jarvis
	"""
	def __init__(self):
		super(JarvisParser, self).__init__(self, 'Jarvis')
